import React, { Component } from 'react'
import Modal from 'react-modal';
import ProductDetails from './product-details';
import '../../resources/stylesheets/product-market.css';

export default class ProductItem extends Component {
    constructor(props) {
        super(props)
        this.state = {
            showDetailsModal: false
        }
        this.toggleDetailsModal = this.toggleDetailsModal.bind(this);
    }

    toggleDetailsModal() {
        const prevState = this.state.showDetailsModal;
        this.setState({ showDetailsModal: !prevState });
    }

    calculateDiscount(price, discount) {
        return (price * ((100 - discount) / 100)).toFixed(2);
    }
    
    render() {
        return (
            <div className="product-item">
                <div id="more-details-img-box">
                    <img 
                        id="prod-img" 
                        alt="" 
                        src={ this.props.item.productImageUrl ? this.props.item.productImageUrl : "-no photo-" } 
                        onClick={ this.toggleDetailsModal }
                    />
                    <p onClick={ this.toggleDetailsModal } id="more-details-text">More Details</p>
                </div>
                <p id="prod-name">{ this.props.item.productName }</p>
                <div id="prod-price">
                    { this.props.item.promo ? 
                    <div id="promo-show">
                        <p id="promo-show-text-original">
                        ${ this.props.item.price }
                        </p>
                        <p id="promo-show-text">
                        ${ this.calculateDiscount(this.props.item.price, this.props.item.promo) }
                        </p>
                    </div> : "$" + this.props.item.price }
                </div>
                { this.props.item.promo ?
                <p id="prod-promotion">
                    { "Save " + this.props.item.promo + "% on this item!"}
                </p> : ""}
                <div className="add-cart-and-quantity">
                    <input id="order-quantity" type="number" placeholder="Qty" />
                    <span id="add-to-cart-button">Add to Cart</span>
                </div>

                <Modal
                    id="product-details-modal"
                    isOpen={ this.state.showDetailsModal }
                    contentLabel="Product Details Modal"
                    onRequestClose={ this.toggleDetailsModal }
                    style={{
                        content: {
                            top: '50%',
                            left: '50%',
                            right: '0',
                            bottom: '0',
                            marginLeft: "-346px",
                            marginTop: "-372px",
                            width: '650px',
                            height: '600px',
                            background: 'white',
                            borderRadius: "10px"
                        },
                        overlay: {
                            position: 'fixed',
                            backgroundColor: 'rgba(0,0,0,0.7)',
                            zIndex: '50'
                        }
                      }}
                >
                    <ProductDetails product={ this.props.item } />
                </Modal>
            </div>
        )
    }
}
